@@ -18,12 +18,15 @@ _HELP_MESSAGE_SCANNER = """
             binary\t\t    Run FOSSLight Binary
             reuse\t\t    Run FOSSLight Reuse
             all\t\t\t    Run all scanners
+            compare\t\t    Compare two FOSSLight reports in yaml format
 
         Options:
             -h\t\t\t    Print help message
-            -p <path>\t\t    Path to analyze
+            -p <path>\t\t    Path to analyze (ex, -p {input_path})
+                                     * Compare mode: Two FOSSLight reports in yaml format (ex, -p {before.yaml} {after.yaml})
             -w <link>\t\t    Link to be analyzed can be downloaded by wget or git clone
-            -f <format>\t\t    Output file format (excel, csv, opossum)
+            -f <format>\t\t    FOSSLight Report file format (excel, yaml)
+                                     * Compare mode: supports excel, json, yaml, html
             -o <output>\t\t    Output directory or file
             -c <number>\t\t    Number of processes to analyze source
             -r\t\t\t    Keep raw data
