@@ -10,10 +10,12 @@ from fosslight_util.help import print_package_version
 
 def main():
     parser = ArgumentParser(description='FOSSLight Scanner', prog='fosslight_scanner', add_help=False)
-    parser.add_argument('mode', nargs='?', help='source| dependency| binary| reuse| all', default="all")
-    parser.add_argument('--path', '-p', help='Path to analyze', type=str, dest='path', default="")
+    parser.add_argument('mode', nargs='?', help='source| dependency| binary| reuse| all| compare', default="all")
+    parser.add_argument('--path', '-p', help='Path to analyze (In compare mode, two FOSSLight reports',
+                        dest='path', nargs='+', default="")
     parser.add_argument('--wget', '-w', help='Link to be analyzed', type=str, dest='link', default="")
-    parser.add_argument('--file', '-f', help='Output file format (excel, csv, opossum)', type=str, dest='file', default="")
+    parser.add_argument('--file', '-f', help='Scanner output file format (excel,yaml), Compare mode (excel,html,yaml,json)',
+                        type=str, dest='file', default="")
     parser.add_argument('--output', '-o', help='Output directory or file', type=str, dest='output', default="")
     parser.add_argument('--dependency', '-d', help='Dependency arguments', type=str, dest='dep_argument', default="")
     parser.add_argument('--url', '-u', help="DB Url", type=str, dest='db_url', default="")
@@ -22,6 +24,7 @@ def main():
     parser.add_argument('--timer', '-t', help='Hide the progress bar',  action='store_true', dest='timer', default=False)
     parser.add_argument('--version', '-v', help='Print version',  action='store_true', dest='version', default=False)
     parser.add_argument('--help', '-h', help='Print help message', action='store_true', dest='help')
+
     try:
         args = parser.parse_args()
     except SystemExit:
